#ifndef NT2_INCLUDE_FUNCTIONS_CSCPI_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_CSCPI_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/cscpi.hpp>

#endif
